==> patch-2.5.5.0_5.zip: app/language/en/settings.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Settings',
	'dashboard' => 'Dashboard',
	'cloudCredentials' => 'Cloud Credentials',
	'cloudProperties' => 'Parablu Installation Properties',
	'globalSettings' => 'Global Settings',
	'dataMigration' => 'Data Migration',
	'adCredentials' => 'Active Directory Credentials',
	'emailConfiguration' => 'Email Configuration',
	'proxyConfiguration' => 'Proxy Configuration',
	'connector' => 'Connector Configuration',
	'domain' => 'Domain Configuration',
	'ssl' => 'SSL Configuration',
	'sslAndEncryption' => 'SSL and Encryption Configuration',
	'encryptionKeySaved' => 'Encryption key successfully saved.',
	'local' => 'Local Storage Settings',
	'smtp' => 'Simple Mail Transfer Protocol Settings',
	'testMail' => 'An Email has been triggered to your email address please check',
	'aadCredentials' => 'Azure Active Directory Credentials',
	// Cloud Credentials
    'azureBlob' => 'Azure Blob Storage',
    'backBlaze' => 'Backblaze',
    'ibmSwift' => 'IBM Cloud - Swift',
    'ibmS3' => 'IBM Cloud - S3',
    'amazonS3' => 'Amazon S3 Buckets',
    'localStorage' => 'Local Storage',
    'microsoft' => 'Microsoft OneDrive for Business',
    'googleDrive' => 'Google Drive',
    'oneDrive' => 'Microsoft OneDrive',
    'S3' => 'S3 Compatibles',

	// Common For all Methods
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',	
	'507'           => '<b>Invalid license key.</b>',
        '508'           => '<b>Invalid license key.</b>',
        '509'           => '<b>Invalid license key.</b>',
        '510'           => '<b>Invalid license key.</b>',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'savedCloudProperties'    	=> 'Parablu Installation properties saved successfully',
	'savedCloudCredentials'    	=> 'Cloud Credentials saved successfully',
	'saveSmtp'    	=> 'SMTP settings saved successfully',
	'savedAdCredentials'    	=> 'Active Directory Credentials saved successfully',
	'removeAdCredentials'    	=> 'Active Directory Credentials deleted',
	'removeAadCredentials'          => 'Azure Active Directory Credentials deleted',
	'removeProxySettings'    	=> 'Proxy Settings deleted',
	'removeCloudCredentials'    	=> 'Cloud Credentials removed',
	
	//place holders
    'cloudNamePH' =>'Enter your Cloud Name',
    'cloudIdentityPH' => 'Enter your Cloud Identity',
    'accessKeyPH' => 'Enter your Access Key',
    'endPointURLPH' => 'Enter your End Point Agent URL',
    'amazonContainerNamePH' => 'Enter your Amazon Container Name',
    'folderNamePH' => 'Enter your folder Name',
    'clientIDPH' => 'Enter your Client ID',
    'secretKeyPH' => 'Enter your Secret Key',
    'redirectURIPH' => 'Enter your Redirect URI',
    'clientResourceURLPH' => 'Enter your client Resource URL',
    'clientTokenURLPH' => 'Enter your client Token URL',
    'portalURLPH' => 'Enter your Portal URL',
    
    //heading
    'cloudName' => 'Cloud Name',
    'cloudType' => 'Cloud Type',
    'clintIDH' => 'Client ID',
    'clintSecretKeyH' => 'Client Secret Key',
    'clintRedirectURIH' => 'Client Redirect URI',
    'clintTokenURLH' => 'Client Token URL',
    'portalURLH' => 'Portal URL',

    'cloudNameInfo' => 'Unique name for your Cloud Storage ',
    'googleDriveClintID' => 'Client ID will be the ID which was provided when you have created a Google Application',
    'oneDriveClintID' => 'Client ID will be the ID which was provided when you have created a Microsoft OneDrive Business Application',
    'googleDriveSecreteKey' => 'Client Secret Key will be the Key which was provided when you have created a Google Application',
    'oneDriveSecreteKey' => 'Client Secret key will be the key which was provided when you have created a Microsoft OneDrive Business Application',
    'clientRedirectURL' => 'Please do not change this URL without administrators knowledge.',
    'resourceURL' => 'Entered URL should be a valid one, example: http://example.com, (Enter your Microsoft SharePoint URL)',
    'portalURL' => 'Please do not change this URL without administrators knowledge, if not specified URL will be automatically detected.',
    'sSLCertificateFile' => 'SSL Certificate File',
    'sSLCertificateChainFile' => 'SSL Certificate Chain File',
    'sSLCertificateKeyFile' => 'SSL Certificate Key File',
    'serverName' => 'Server Name',
    'certificateFile' => 'SSL Certificate File should be your DigiCert certificate file (eg. your_domain_name.crt).',
    'chainFile' => 'SSL Certificate Chain File should be the DigiCert intermediate certificate file (DigiCertCA.crt).',
    'keyFile' => 'SSL Certificate Key File should be the key file generated when you created the CSR.',
    'serverNameExample' => 'Example:- www.parablu.com',
    'addYourEncryptionConfiguration' => 'Add your Encryption Configuration',
    'bluVaultForEndPoint' => 'BluVault For End Point',
    'bluVaultForServers' => 'BluVault For Servers',
    'bluSyncEFSS' => 'BluSync - EFSS',
    'saltkey' => 'Salt key',
    'partEncryptionkey' => 'This will be a part of the Encryption key',
    
    //COMPONENT PROPERTIES - BLUKRYPT
    "componentProperties" => "Component Properties",
    "ftpHost"=>"Ftp Host",
    "syncUploadPath"=>"Sync Upload Path",
    "ftpUser"=>"Ftp User",
    "ftpPwd"=>"Ftp Pwd",
    "odbFrequencyCallValue"=>"Odb Frequency Call Value",
    "proxyUserName"=>"Proxy User Name",
    "proxyPort"=>"Proxy Port",
    "proxyHost"=>"Proxy Host",
    "proxyPassword"=>"Proxy Password",
    "chunkUpdateMaxRetry"=>"Chunk Update Max Retry",
    "noOfJobThreads"=>"No Of Job Threads",
    "deleteBkpTblWhenChnkNotFound"=>"Delete Backup Table When Chnk Not Found",
    "updateGatewayWhenChunkNotFound"=>"Update Gateway When Chunk Not Found",
    "chunkTotalBuckets"=>"Chunk Total Buckets",
    "odbRetryFolderVal"=>"Odb Retry Folder Value",
    "odbUserAgentVal"=>"Odb User Agent Value",
    "gatewayName"=>"Gateway Name",
    "localdbhost"=>"Local Db Host",
    "paracloudUrl"=>"Paracloud Url",
    "queryLimit"=>"Query Limit",
    "policyRefresh" => "Policy Refresh",
    "encryptionEnabled"=>"Encryption Enabled",
    "syncFtpEnabled"=>"Sync Ftp Enabled",
    "localStorageEnabled"=>"Local Storage Enabled",
    "chunkColQueryRequired"=>"Chunk Column Query Required",
    "bkpColQueryRequired"=>"Backup Column Query Required",
    "pgOverloadLimit"=>"PG Overload Limit",
    "pgOverLoadInactivityPeriod"=>"PG Overload Inactivity Period",
    "resoreQueryLimit"=>"Resore Query Limit",
    "noOfThreads"=>"No of Threads",    
    "stopJobsEnabled"=>"Stop Jobs Enabled",


//COMPONENT PROPERTIES - PARACLOUD
    "devAllowPerCollection" => "Dev Allow Per Collection",
    "chunkTotalBuckets" => "Chunk Total Buckets",
    "devicesPerUser" => "Devices Per User",
    "keyForLoad" => "Key For Load",
    "paracloudDownloadPath" => "Paracloud Download Path",
    "updateParacloudScriptName" => "Update Paracloud Script Name",
    "azureStorageAccountName" => "Azure Storage Account Name",
    "azureStorageAccountKey" => "Azure Storage Account Key",
    "noOfMonthsOldRecordToDeleteForSyncOverview" => "No of Months Old Record To Delete For Sync Overview",
    "impUsersPolicyNames" => "Imp Users Policy Names",
    "superUserName" => "Super User Name",
    "restoreurl" => "Restore Url",
    "bkpColQueryRequired" => "Backup Column Query Required",
    "chunkColQueryRequired" => "Chunk Column Query Required",
    "showAddADAttributeEnabled" => "Show Add AD Attribute Enabled",
    "azureGateway" => "Azure Gateway",
    "devcertprivkeypath" => "Device Cert Private Key Path",
    
);

==> patch-2.5.5.3_7_2.zip: app/language/en/settings.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Settings',
	'dashboard' => 'Dashboard',
	'cloudCredentials' => 'Destination Storage Credentials',
	'siemCredentials' => 'SIEM Credentials',
	'cloudProperties' => 'Parablu Installation Properties',
	'globalSettings' => 'Global Settings',
	'dataMigration' => 'Data Migration',
	'adCredentials' => 'Active Directory Credentials',
	'emailConfiguration' => 'Email Configuration',
	'proxyConfiguration' => 'Proxy Configuration',
	'connector' => 'Connector Configuration',
	'domain' => 'Domain Configuration',
	'ssl' => 'SSL Configuration',
	'sslAndEncryption' => 'SSL and Encryption Configuration',
	'encryptionKeySaved' => 'Encryption key successfully saved.',
	'local' => 'Local Storage Settings',
	'smtp' => 'Simple Mail Transfer Protocol Settings',
	'testMail' => 'An Email has been triggered to your email address please check',
	'aadCredentials' => 'Azure Active Directory Credentials',
	// Cloud Credentials
    'azureBlob' => 'Azure Blob Storage',
    'backBlaze' => 'Backblaze',
    'ibmSwift' => 'IBM Cloud - Swift',
    'ibmS3' => 'IBM Cloud - S3',
    'amazonS3' => 'Amazon S3 Buckets',
    'localStorage' => 'Local Storage',
    'microsoft' => 'Microsoft OneDrive for Business',
    'googleDrive' => 'Google Drive',
    'oneDrive' => 'Microsoft OneDrive',
    'S3' => 'S3 Compatibles',

	// Common For all Methods
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',	
	'507'           => '<b>Invalid license key.</b>',
        '508'           => '<b>Invalid license key.</b>',
        '509'           => '<b>Invalid license key.</b>',
        '510'           => '<b>Invalid license key.</b>',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'savedCloudProperties'    	=> 'Parablu Installation properties saved successfully',
	'savedCloudCredentials'    	=> 'Cloud Credentials saved successfully',
	'savedSiemCredentials'         	=> 'Siem Credentials saved successfully',
	'saveSmtp'    			=> 'SMTP settings saved successfully',
	'savedAdCredentials'    	=> 'Active Directory Credentials saved successfully',
	'removeAdCredentials'    	=> 'Active Directory Credentials deleted',
	'removeAadCredentials'          => 'Azure Active Directory Credentials deleted',
	'removeProxySettings'    	=> 'Proxy Settings deleted',
	'removeCloudCredentials'    	=> 'Cloud Credentials removed',
	
	//place holders
    'cloudNamePH' =>'Enter your Cloud Name',
    'cloudIdentityPH' => 'Enter your Cloud Identity',
    'accessKeyPH' => 'Enter your Access Key',
    'endPointURLPH' => 'Enter your End Point Agent URL',
    'amazonContainerNamePH' => 'Enter your Amazon Container Name',
    'folderNamePH' => 'Enter your folder Name',
    'clientIDPH' => 'Enter your Client ID',
    'secretKeyPH' => 'Enter your Secret Key',
    'redirectURIPH' => 'Enter your Redirect URI',
    'clientResourceURLPH' => 'Enter your client Resource URL',
    'clientTokenURLPH' => 'Enter your client Token URL',
    'portalURLPH' => 'Enter your Portal URL',
    
    //heading
    'cloudName' => 'Cloud Name',
    'cloudType' => 'Cloud Type',
    'clintIDH' => 'Client ID',
    'clintSecretKeyH' => 'Client Secret Key',
    'clintRedirectURIH' => 'Client Redirect URI',
    'clintTokenURLH' => 'Client Token URL',
    'portalURLH' => 'Portal URL',

    'cloudNameInfo' => 'Unique name for your Cloud Storage ',
    'googleDriveClintID' => 'Client ID will be the ID which was provided when you have created a Google Application',
    'oneDriveClintID' => 'Client ID will be the ID which was provided when you have created a Microsoft OneDrive Business Application',
    'googleDriveSecreteKey' => 'Client Secret Key will be the Key which was provided when you have created a Google Application',
    'oneDriveSecreteKey' => 'Client Secret key will be the key which was provided when you have created a Microsoft OneDrive Business Application',
    'clientRedirectURL' => 'Please do not change this URL without administrators knowledge.',
    'resourceURL' => 'Entered URL should be a valid one, example: http://example.com, (Enter your Microsoft SharePoint URL)',
    'portalURL' => 'Please do not change this URL without administrators knowledge, if not specified URL will be automatically detected.',
    'sSLCertificateFile' => 'SSL Certificate File',
    'sSLCertificateChainFile' => 'SSL Certificate Chain File',
    'sSLCertificateKeyFile' => 'SSL Certificate Key File',
    'serverName' => 'Server Name',
    'certificateFile' => 'SSL Certificate File should be your DigiCert certificate file (eg. your_domain_name.crt).',
    'chainFile' => 'SSL Certificate Chain File should be the DigiCert intermediate certificate file (DigiCertCA.crt).',
    'keyFile' => 'SSL Certificate Key File should be the key file generated when you created the CSR.',
    'serverNameExample' => 'Example:- www.parablu.com',
    'addYourEncryptionConfiguration' => 'Add your Encryption Configuration',
    'bluVaultForEndPoint' => 'BluVault For End Point',
    'bluVaultForServers' => 'BluVault For Servers',
    'bluSyncEFSS' => 'BluSync - EFSS',
    'saltkey' => 'Salt key',
    'partEncryptionkey' => 'This will be a part of the Encryption key',
    
    //COMPONENT PROPERTIES - BLUKRYPT
    "componentProperties" => "Component Properties",
    "ftpHost"=>"Ftp Host",
    "syncUploadPath"=>"Sync Upload Path",
    "ftpUser"=>"Ftp User",
    "ftpPwd"=>"Ftp Pwd",
    "odbFrequencyCallValue"=>"Odb Frequency Call Value",
    "proxyUserName"=>"Proxy User Name",
    "proxyPort"=>"Proxy Port",
    "proxyHost"=>"Proxy Host",
    "proxyPassword"=>"Proxy Password",
    "chunkUpdateMaxRetry"=>"Chunk Update Max Retry",
    "noOfJobThreads"=>"No Of Job Threads",
    "deleteBkpTblWhenChnkNotFound"=>"Delete Backup Table When Chnk Not Found",
    "updateGatewayWhenChunkNotFound"=>"Update Gateway When Chunk Not Found",
    "chunkTotalBuckets"=>"Chunk Total Buckets",
    "odbRetryFolderVal"=>"Odb Retry Folder Value",
    "odbUserAgentVal"=>"Odb User Agent Value",
    "gatewayName"=>"Gateway Name",
    "localdbhost"=>"Local Db Host",
    "paracloudUrl"=>"Paracloud Url",
    "queryLimit"=>"Query Limit",
    "policyRefresh" => "Policy Refresh",
    "encryptionEnabled"=>"Encryption Enabled",
    "syncFtpEnabled"=>"Sync Ftp Enabled",
    "localStorageEnabled"=>"Local Storage Enabled",
    "chunkColQueryRequired"=>"Chunk Column Query Required",
    "bkpColQueryRequired"=>"Backup Column Query Required",
    "pgOverloadLimit"=>"PG Overload Limit",
    "pgOverLoadInactivityPeriod"=>"PG Overload Inactivity Period",
    "resoreQueryLimit"=>"Resore Query Limit",
    "noOfThreads"=>"No of Threads",    
    "stopJobsEnabled"=>"Stop Jobs Enabled",


//COMPONENT PROPERTIES - PARACLOUD
    "devAllowPerCollection" => "Dev Allow Per Collection",
    "chunkTotalBuckets" => "Chunk Total Buckets",
    "devicesPerUser" => "Devices Per User",
    "keyForLoad" => "Key For Load",
    "paracloudDownloadPath" => "Paracloud Download Path",
    "updateParacloudScriptName" => "Update Paracloud Script Name",
    "azureStorageAccountName" => "Azure Storage Account Name",
    "azureStorageAccountKey" => "Azure Storage Account Key",
    "noOfMonthsOldRecordToDeleteForSyncOverview" => "No of Months Old Record To Delete For Sync Overview",
    "impUsersPolicyNames" => "Imp Users Policy Names",
    "superUserName" => "Super User Name",
    "restoreurl" => "Restore Url",
    "bkpColQueryRequired" => "Backup Column Query Required",
    "chunkColQueryRequired" => "Chunk Column Query Required",
    "showAddADAttributeEnabled" => "Show Add AD Attribute Enabled",
    "azureGateway" => "Azure Gateway",
    "devcertprivkeypath" => "Device Cert Private Key Path",
    
);
